@@ -13,9 +13,6 @@ RESTPLUS_MASK_SWAGGER = os.getenv('RESTPLUS_MASK_SWAGGER', False)
 RESTPLUS_ERROR_404_HELP = os.getenv('RESTPLUS_ERROR_404_HELP', False)
 
 # Logging
-INFLUX_PROXY_LOG = "/var/log/influx_proxy"
-
-LOG_PATH = os.getenv('LOG_PATH', INFLUX_PROXY_LOG)
-MONITORING_ELASTIC_NODE = os.getenv('MONITORING_ELASTIC_NODE', '10.200.129.60')
+LOG_PATH = os.getenv('LOG_PATH', '/var/log/influx-rp-generator/')
 SERVICE_NAME = os.getenv('SERVICE_NAME', 'influx_proxy')
 LOG_LEVEL = os.getenv('LOG_LEVEL', 'INFO')
